from setuptools import setup, find_packages

with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='pycfd',
    version='1.0.1',
    author='George Cane',
    author_email='zenwhats@gmail.com',
    description='A Python package for CFD, FEA, FEM, FDM, and PDE solving',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/Georgecane/pycfd',
    project_urls={
        'Documentation': 'https://github.com/Georgecane/pycfd/wiki',
        'Source': 'https://github.com/Georgecane/pycfd',
        'Bug Tracker': 'https://github.com/Georgecane/pycfd/issues',
    },
    packages=find_packages(),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.13',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    python_requires='>=3.8',
    install_requires=[
        'numpy',
        'scipy',
        'sympy',
        'matplotlib',
    ],
    extras_require={
        'dev': ['pytest', 'black', 'flake8'],
        'docs': ['sphinx', 'sphinx-rtd-theme'],
    },
    include_package_data=True,
    zip_safe=False,
    license='Apache-2.0',
    keywords='CFD FEA FEM FDM PDE scientific computing',
)
